#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# 25 August, 2018 by FUJIWARA Teruyoshi <tf@dsl.gr.jp>
#
# This script scrapes a temperature result of a day from the web page of Japan Meteorological Agency.

import requests
import bs4
import csv
import os
import sys
import re
import datetime
import pytz

url = 'http://www.jma.go.jp/jp/amedas_h/yesterday-51116.html' # Toyota City, Aichi Pref., Japan
timezone = 'Asia/Tokyo'
tz_abbrev = 'JST'

def datetime_0to24(year, month, day, hour, minutes):
    next_day = False
    if hour == 24:
        hour = 0
        next_day = True
    d = datetime.datetime(year, month, day, hour, 0, 0, 0, pytz.timezone(timezone))
    if next_day:
        d = d + datetime.timedelta(days = 1)
    return d

def main():
    reload(sys)
    sys.setdefaultencoding('utf-8')

    try:
        res = requests.get(url)
        res.raise_for_status()
    except Exception:
        print('Exception: ' + str(res.status_code))
        exit()

    soup = bs4.BeautifulSoup(res.text, "html.parser")

    date = soup.find_all("td",{"class":"td_title height2"})
    m = re.search(r'(?P<year>[0-9]+)年(?P<month>[0-9]+)月(?P<day>[0-9]+)日', str(date[0]))

    tables = soup.find_all("table",{"id":"tbl_list"})
    if (len(tables) != 1):
        raise Exception("Table not found.")
        exit()

    table = tables[0]
    trs = table.find_all("tr")

    columns = []
    rows = [columns]

    regex = re.compile(r'[0-9]+')
    for tr in trs:
        row = [td.text for td in tr.find_all(["td", "th"])]
        res = regex.match(str(row[0]))
        if (res):
            year = int(m.group('year'))
            month = int(m.group('month'))
            day = int(m.group('day'))
            hour = int(row[0])
            d = datetime_0to24(year, month, day, hour, 0)
            row[0] = d.strftime("%Y/%m/%d %H:%M:%S " + tz_abbrev)
            rows.append(row)

    writer = csv.writer(sys.stdout, lineterminator="\n")
    writer.writerows(rows)

if __name__ == "__main__":
    main()
